test/hotspot/jtreg/runtime/logging/MonitorInflationTest.java
changeset 53588 a5f46c4690f8
parent 53557 4cfe0e5a3b79
--- a/test/hotspot/jtreg/runtime/logging/MonitorInflationTest.java	Thu Jan 31 10:29:53 2019 -0500
+++ b/test/hotspot/jtreg/runtime/logging/MonitorInflationTest.java	Thu Jan 31 11:19:58 2019 -0500
@@ -24,7 +24,7 @@
 /*
  * @test
  * @bug 8133885
  * @summary monitorinflation=debug should have logging from each of the statements in the code
  * @library /test/lib
  * @modules java.base/jdk.internal.misc
  *          java.management
@@ -50,7 +50,7 @@
     }
 
     public static void main(String[] args) throws Exception {
-        ProcessBuilder pb = ProcessTools.createJavaProcessBuilder("-Xlog:monitorinflation=debug",
+        ProcessBuilder pb = ProcessTools.createJavaProcessBuilder("-Xlog:monitorinflation=trace",
                                                                   InnerClass.class.getName());
         analyzeOutputOn(pb);
@@ -24,7 +24,7 @@
  * @test
  * @bug 8133885
- * @summary monitorinflation=debug should have logging from each of the statements in the code
+ * @summary monitorinflation=trace should have logging from each of the statements in the code
  * @library /test/lib
  * @modules java.base/jdk.internal.misc